@@ -307,7 +307,7 @@ ev_attachment_save (EvAttachment *attachment,
 		g_set_error (error,
 			     EV_ATTACHMENT_ERROR, 
 			     ioerror->code,
-			     _("Couldn't save attachment “%s”: %s"),
+			     _("Couldn’t save attachment “%s”: %s"),
 			     uri, 
 			     ioerror->message);
 
@@ -328,7 +328,7 @@ ev_attachment_save (EvAttachment *attachment,
 		g_set_error (error,
 			     EV_ATTACHMENT_ERROR,
 			     ioerror->code,
-			     _("Couldn't save attachment “%s”: %s"),
+			     _("Couldn’t save attachment “%s”: %s"),
 			     uri,
 			     ioerror->message);
 		
@@ -376,7 +376,7 @@ ev_attachment_launch_app (EvAttachment *attachment,
 		g_set_error (error,
 			     EV_ATTACHMENT_ERROR,
 			     (gint) result,
-			     _("Couldn't open attachment “%s”: %s"),
+			     _("Couldn’t open attachment “%s”: %s"),
 			     attachment->priv->name,
 			     ioerror->message);
 
@@ -411,7 +411,7 @@ ev_attachment_open (EvAttachment *attachment,
 		g_set_error (error,
 			     EV_ATTACHMENT_ERROR,
 			     0,
-			     _("Couldn't open attachment “%s”"),
+			     _("Couldn’t open attachment “%s”"),
 			     attachment->priv->name);
 		
 		return FALSE;
