@@ -129,6 +129,10 @@ static inline gboolean
 find_check_refresh_rate (EvJobFind *job,
                          gint       page_rate)
 {
+        /* Always update if this is the last page of the search */
+        if ((job->current_page + 1) % job->n_pages == job->start_page)
+                return TRUE;
+
         return ((job->current_page % (gint)((job->n_pages / page_rate) + 1)) == 0);
 }
 
@@ -588,14 +592,12 @@ ev_search_box_init (EvSearchBox *box)
 
         priv->prev_button = gtk_button_new_from_icon_name ("go-up-symbolic", GTK_ICON_SIZE_MENU);
         gtk_widget_set_tooltip_text (priv->prev_button, _("Find previous occurrence of the search string"));
-        gtk_widget_set_can_focus (priv->prev_button, FALSE);
         gtk_widget_set_sensitive (priv->prev_button, FALSE);
         gtk_container_add (GTK_CONTAINER (box), priv->prev_button);
         gtk_widget_show (priv->prev_button);
 
         priv->next_button = gtk_button_new_from_icon_name ("go-down-symbolic", GTK_ICON_SIZE_MENU);
         gtk_widget_set_tooltip_text (priv->next_button, _("Find next occurrence of the search string"));
-        gtk_widget_set_can_focus (priv->next_button, FALSE);
         gtk_widget_set_sensitive (priv->next_button, FALSE);
         gtk_container_add (GTK_CONTAINER (box), priv->next_button);
         gtk_widget_show (priv->next_button);
