@@ -1039,13 +1039,13 @@ ev_application_startup (GApplication *gapplication)
           "win.close",                  "<Ctrl>W", NULL,
           "win.escape",                 "Escape", NULL,
           "win.find",                   "<Ctrl>F", "slash", NULL,
-          "win.find-next",              "<Ctrl>G", NULL,
-          "win.find-previous",          "<Ctrl><Shift>G", NULL,
+          "win.find-next",              "<Ctrl>G", "F3", NULL,
+          "win.find-previous",          "<Ctrl><Shift>G", "<Shift>F3", NULL,
           "win.select-page",            "<Ctrl>L", NULL,
           "win.go-backwards",           "<Shift>Page_Up", NULL,
           "win.go-forward",             "<Shift>Page_Down", NULL,
-          "win.go-next-page",           "n", NULL,
-          "win.go-previous-page",       "p", NULL,
+          "win.go-next-page",           "n", "<Ctrl>Page_Down", NULL,
+          "win.go-previous-page",       "p", "<Ctrl>Page_Up", NULL,
           "win.go-back-history",        "<alt>P", "Back", NULL,
           "win.go-forward-history",     "<alt>N", "Forward", NULL,
           "win.sizing-mode::fit-page",  "f", NULL,
