@@ -40,7 +40,7 @@ struct _EvWindowTitle
 	EvWindow *window;
 	EvWindowTitleType type;
 	EvDocument *document;
-	char *filename;
+	char *uri;
         char *doc_title;
 };
 
@@ -57,6 +57,19 @@ static const BadTitleEntry bad_prefixes[] = {
 	{ EV_BACKEND_PDF, "Microsoft PowerPoint - " }
 };
 
+static char *
+get_filename_from_uri (const char *uri)
+{
+	char *filename;
+	char *basename;
+	
+	filename = g_uri_unescape_string (uri, NULL);
+	basename = g_path_get_basename (filename);
+	g_free(filename);
+
+	return basename;
+}
+
 /* Some docs report titles with confusing extensions (ex. .doc for pdf).
 	   Erase the confusing extension of the title */
 static void
@@ -70,10 +83,13 @@ ev_window_title_sanitize_title (EvWindowTitle *window_title, char **title) {
 		if (g_ascii_strcasecmp (bad_extensions[i].backend, backend) == 0 && 
 		    g_str_has_suffix (*title, bad_extensions[i].text)) {
 			char *new_title;
+			char *filename = get_filename_from_uri (window_title->uri);
 
 			new_title = g_strndup (*title, strlen(*title) - strlen(bad_extensions[i].text));
 			g_free (*title);
 			*title = new_title;
+
+			g_free (filename);
 		}
 	}
 	for (i = 0; i < G_N_ELEMENTS (bad_prefixes); i++) {
@@ -103,11 +119,11 @@ ev_window_title_update (EvWindowTitle *window_title)
                 return;
         }
 
-	if (window_title->doc_title && window_title->filename) {
+	if (window_title->doc_title && window_title->uri) {
                 title = g_strdup (window_title->doc_title);
                 ev_window_title_sanitize_title (window_title, &title);
 
-		subtitle = window_title->filename;
+		subtitle = get_filename_from_uri (window_title->uri);
 
 		title_header = title;
 		title = g_strdup_printf ("%s — %s", subtitle, title);
@@ -117,8 +133,8 @@ ev_window_title_update (EvWindowTitle *window_title)
                         if (*p == '\n')
                                 *p = ' ';
                 }
-	} else if (window_title->filename) {
-		title = g_strdup (window_title->filename);
+	} else if (window_title->uri) {
+		title = get_filename_from_uri (window_title->uri);
 	} else if (!title) {
 		title = g_strdup (_("Document Viewer"));
 	}
@@ -148,6 +164,7 @@ ev_window_title_update (EvWindowTitle *window_title)
 	}
 
 	g_free (title);
+	g_free (subtitle);
 	g_free (title_header);
 }
 
@@ -216,14 +233,14 @@ ev_window_title_set_document (EvWindowTitle *window_title,
 }
 
 void
-ev_window_title_set_filename (EvWindowTitle *window_title,
-			      const char    *filename)
+ev_window_title_set_uri (EvWindowTitle *window_title,
+			 const char    *uri)
 {
-        if (g_strcmp0 (filename, window_title->filename) == 0)
+        if (g_strcmp0 (uri, window_title->uri) == 0)
                 return;
 
-	g_free (window_title->filename);
-	window_title->filename = g_strdup (filename);
+	g_free (window_title->uri);
+	window_title->uri = g_strdup (uri);
 
 	ev_window_title_update (window_title);
 }
@@ -234,6 +251,6 @@ ev_window_title_free (EvWindowTitle *window_title)
         if (window_title->document)
                 g_object_weak_unref (G_OBJECT (window_title->document), (GWeakNotify)document_destroyed_cb, window_title);
         g_free (window_title->doc_title);
-	g_free (window_title->filename);
+	g_free (window_title->uri);
 	g_free (window_title);
 }
