@@ -101,15 +101,42 @@ delete_temp_file (GFile *file)
 	g_object_unref (file);
 }
 
+static char *
+get_target_uri (GFile *file)
+{
+	GFileInfo *info;
+	char *target;
+
+	info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI, G_FILE_QUERY_INFO_NONE, NULL, NULL);
+	if (info == NULL)
+		return NULL;
+	target = g_strdup (g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI));
+	g_object_unref (info);
+
+	return target;
+}
+
+static char *
+get_local_path (GFile *file)
+{
+	if (g_file_has_uri_scheme (file, "trash") != FALSE ||
+	    g_file_has_uri_scheme (file, "recent") != FALSE) {
+		return get_target_uri (file);
+	}
+	return g_file_get_path (file);
+}
+
 static EvDocument *
 evince_thumbnailer_get_document (GFile *file)
 {
 	EvDocument *document = NULL;
-	gchar      *uri;
+	gchar      *uri, *path;
 	GFile      *tmp_file = NULL;
 	GError     *error = NULL;
 
-	if (!g_file_is_native (file)) {
+	path = get_local_path (file);
+
+	if (!path) {
 		gchar *base_name, *template;
 
 		base_name = g_file_get_basename (file);
@@ -136,10 +163,11 @@ evince_thumbnailer_get_document (GFile *file)
 		}
 		uri = g_file_get_uri (tmp_file);
 	} else {
-		uri = g_file_get_uri (file);
+		uri = g_filename_to_uri (path, NULL, NULL);
+		g_free (path);
 	}
 
-	document = ev_document_factory_get_document (uri, &error);
+	document = ev_document_factory_get_document_full (uri, EV_DOCUMENT_LOAD_FLAG_NO_CACHE, &error);
 	if (tmp_file) {
 		if (document) {
 			g_object_weak_ref (G_OBJECT (document),
